==> down.php?SDK=cocos_V1.20.3.2.zip: cocos_V1.20.3.2/Android/sample/c2s/Classes/PushParamScene.cpp <==
//
//  PushParamScene.cpp
//  HIVE_SDK_Cocos_Sample
//
//  Created by sjyong on 2021/10/20.
//

#include "PushParamScene.hpp"
#include "ParameterDataManager.hpp"
#include "C2SPush.h"
#include "ui/CocosGUI.h"

using namespace cocos2d;
using namespace cocos2d::ui;
using namespace hive;

#include <map>

using namespace std;

bool PushParamScene::init()
{
    if(!BaseView::init())
        return false;

    addButton("OK", BUTTON_OK);

    scheduleUpdate();

    return true;
}

void PushParamScene::update(float dt)
{
    BaseView::update(dt);

    static bool firstRun = true;
    if (firstRun) {
        firstRun = false;
    }
}

void PushParamScene::onButtonEvent(int buttonTag)
{
    if (buttonTag != BUTTON_OK) {
        return;
    }

    setCompletionHandler();
    setCompletionHandler = NULL;
    this->popView();
}

void PushParamScene::showParameters(int tag)
{
    api = static_cast<C2SModuleAPIList::PushAPI>(tag);
    switch (api) {
        // Common
        case C2SModuleAPIList::PUSH_SET_AGREE:
        {
            showPushSetAgreeParam([=](){
                int notice = getSelectedToggleButtonIndex(TOGGLE_BUTTON_NOTICE);
                int night = getSelectedToggleButtonIndex(TOGGLE_BUTTON_NIGHT);

                ParameterDataManager::getInstance()->pushParams->setNotice(static_cast<Push_BoolType>(notice));
                ParameterDataManager::getInstance()->pushParams->setNight(static_cast<Push_BoolType>(night));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH:
        {
            showPushRegisterLocalPushParam([=](){
                setRegisterLocalPushParam();
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_EX:
        {
            showPushRegisterLocalPushExParam([=](){
                setRegisterLocalPushParam();

                string broadcastAction = getEditboxValue(EDITBOX_BROADCAST_ACTION);
                ParameterDataManager::getInstance()->pushParams->setBroadcastAction(broadcastAction);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_UNREGISTER_LOCAL_PUSH:
        {
            showPushUnRegisterLocalPushParam([=](){
                string pushID = getEditboxValue(EDITBOX_PUSH_ID);
                ParameterDataManager::getInstance()->pushParams->setPushID(stoi(pushID));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_UID:
        {
            showPushSetUidParam([=](){
                string uid = getEditboxValue(EDITBOX_UID);
                ParameterDataManager::getInstance()->commonParams->setUid(uid);
            });
            break;
        }

        // iOS
        case C2SModuleAPIList::PUSH_SET_FOREGROUND:
        {
            showPushSetForegroundParam([=](){
                int remote = getSelectedToggleButtonIndex(TOGGLE_BUTTON_REMOTE);
                int local = getSelectedToggleButtonIndex(TOGGLE_BUTTON_LOCAL);

                ParameterDataManager::getInstance()->pushParams->setRemote(static_cast<Push_BoolType>(remote));
                ParameterDataManager::getInstance()->pushParams->setLocal(static_cast<Push_BoolType>(local));

            });
            break;
        }

        // Android
        case C2SModuleAPIList::PUSH_SET_PUSH:
        {
            showPushSetPushParam([=](){
                int isPush = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_PUSH);
                ParameterDataManager::getInstance()->pushParams->setIsPush(intToPushUserSetting(isPush));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_SOUND:
        {
            showPushSetSoundParam([=](){
                int isSound = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_SOUND);
                ParameterDataManager::getInstance()->pushParams->setIsSound(intToPushUserSetting(isSound));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_VIB:
        {
            showPushSetVibParam([=](){
                int isVib = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_VIB);
                ParameterDataManager::getInstance()->pushParams->setIsVib(intToPushUserSetting(isVib));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_BIG:
        {
            showPushRegisterLocalPushBigParam([=](){
                setRegisterLocalPushParam();

                string bigmsg = getEditboxValue(EDITBOX_BIG_MSG);
                string broadcastAction = getEditboxValue(EDITBOX_BROADCAST_ACTION);

                ParameterDataManager::getInstance()->pushParams->setBigMsg(bigmsg);
                ParameterDataManager::getInstance()->pushParams->setBroadcastAction(broadcastAction);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_DATA:
        {
            showPushRegisterLocalPushParam([=](){
                string jsonPushData = getEditboxValue(EDITBOX_JSON_PUSH_DATA);
                ParameterDataManager::getInstance()->pushParams->setJsonPushData(jsonPushData);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_OPERATION_LOCAL_PUSH_ON_RUNNING:
        {
            showPushSetOperationLocalPushOnRunningParam([=](){
                int boolean = getSelectedToggleButtonIndex(TOGGLE_BUTTON_BOOLEAN);
                ParameterDataManager::getInstance()->pushParams->setBoolean(boolean);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_OPERATION_GCM_PUSH_ON_RUNNING:
        {
            showPushSetOperationGCMPushOnRunningParam([=](){
                int boolean = getSelectedToggleButtonIndex(TOGGLE_BUTTON_BOOLEAN);
                ParameterDataManager::getInstance()->pushParams->setBoolean(boolean);
            });
            break;
        }
        default:
            break;
    }
}

// MARK: Common
void PushParamScene::showPushSetAgreeParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetAgree -");
    setCompletionHandler = completionHandler;

    Push_BoolType notice = ParameterDataManager::getInstance()->pushParams->getNotice();
    Push_BoolType night = ParameterDataManager::getInstance()->pushParams->getNight();

    addTrueFalseToggleButton("notice : ", int(notice), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_NOTICE);
    addTrueFalseToggleButton("night : ", int(night), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_NIGHT);
}

void PushParamScene::showPushRegisterLocalPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPush -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();
}

void PushParamScene::showPushRegisterLocalPushExParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushEx -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();

    string broadcastAction = ParameterDataManager::getInstance()->pushParams->getBroadcastAction();

    addEditBox("broadcastAction : ", broadcastAction.c_str(), "", EDITBOX_BROADCAST_ACTION);
}

void PushParamScene::showPushUnRegisterLocalPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- UnRegisterLocalPush -");
    setCompletionHandler = completionHandler;

    int pushID = ParameterDataManager::getInstance()->pushParams->getPushID();

    addEditBox("pushID : ", to_string(pushID).c_str(), "", EDITBOX_PUSH_ID);
}

void PushParamScene::showPushSetUidParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetUid -");
    setCompletionHandler = completionHandler;

    string uid = ParameterDataManager::getInstance()->commonParams->getUid();

    addEditBox("pushID : ", uid.c_str(), "", EDITBOX_PUSH_ID);
}

// MARK: iOS
void PushParamScene::showPushSetForegroundParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetForeground -");
    setCompletionHandler = completionHandler;

    Push_BoolType remote = ParameterDataManager::getInstance()->pushParams->getRemote();
    Push_BoolType local = ParameterDataManager::getInstance()->pushParams->getLocal();

    addTrueFalseToggleButton("remote : ", int(remote), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_REMOTE);
    addTrueFalseToggleButton("local : ", int(local), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_LOCAL);
}

// MARK: Android
void PushParamScene::showPushSetPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetPush -");
    setCompletionHandler = completionHandler;

    Push_BoolType isPush = ParameterDataManager::getInstance()->pushParams->getIsPush();
    int isPushValue = 0;
    if(isPush == Push_TRUE) {
        isPushValue = 1;
    } else {
        isPushValue = 0;
    }

    addTrueFalseToggleButton("isPush : ", isPushValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_PUSH);
}

void PushParamScene::showPushSetSoundParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetSound -");
    setCompletionHandler = completionHandler;

    Push_BoolType isSound = ParameterDataManager::getInstance()->pushParams->getIsSound();
    int isSoundValue = 0;
    if(isSound == Push_TRUE) {
        isSoundValue = 1;
    } else {
        isSoundValue = 0;
    }

    addTrueFalseToggleButton("isSound : ", isSoundValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_SOUND);
}

void PushParamScene::showPushSetVibParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetVib -");
    setCompletionHandler = completionHandler;

    Push_BoolType isVib = ParameterDataManager::getInstance()->pushParams->getIsVib();
    int isVibValue = 0;
    if(isVib == Push_TRUE) {
        isVibValue = 1;
    } else {
        isVibValue = 0;
    }

    addTrueFalseToggleButton("isVib : ", isVibValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_VIB);
}

void PushParamScene::showPushRegisterLocalPushBigParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushBig -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();

    string bigmsg = ParameterDataManager::getInstance()->pushParams->getBigMsg();
    string broadcastAction = ParameterDataManager::getInstance()->pushParams->getBroadcastAction();

    addEditBox("bigmsg : ", bigmsg.c_str(), "", EDITBOX_BIG_MSG);
    addEditBox("broadcastAction : ", broadcastAction.c_str(), "", EDITBOX_BROADCAST_ACTION);
}

void PushParamScene::showPushRegisterLocalPushDataParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushData -");
    setCompletionHandler = completionHandler;

    string jsonPushData = ParameterDataManager::getInstance()->pushParams->getJsonPushData();

    addEditBox("jsonPushData : ", jsonPushData.c_str(), "", EDITBOX_JSON_PUSH_DATA);
}

void PushParamScene::showPushSetOperationLocalPushOnRunningParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetOperationLocalPushOnRunning -");
    setCompletionHandler = completionHandler;

    int boolean = ParameterDataManager::getInstance()->pushParams->getBoolean();

    addTrueFalseToggleButton("boolean : ", boolean, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_BOOLEAN);
}

void PushParamScene::showPushSetOperationGCMPushOnRunningParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetOperationGCMPushOnRunning -");
    setCompletionHandler = completionHandler;

    int boolean = ParameterDataManager::getInstance()->pushParams->getBoolean();

    addTrueFalseToggleButton("boolean : ", boolean, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_BOOLEAN);
}

void PushParamScene::addRegisterLocalPushParamButtons()
{
    int pushID = ParameterDataManager::getInstance()->pushParams->getPushID();
    string title = ParameterDataManager::getInstance()->pushParams->getTitle();
    string msg = ParameterDataManager::getInstance()->pushParams->getMsg();
    string ticker = ParameterDataManager::getInstance()->pushParams->getTicker();
    string type = ParameterDataManager::getInstance()->pushParams->getType();
    string icon = ParameterDataManager::getInstance()->pushParams->getIcon();
    string sound = ParameterDataManager::getInstance()->pushParams->getSound();
    string active = ParameterDataManager::getInstance()->pushParams->getActive();
    long after = ParameterDataManager::getInstance()->pushParams->getAfter();

    addEditBox("pushID : ", to_string(pushID).c_str(), "", EDITBOX_PUSH_ID);
    addEditBox("title : ", title.c_str(), "", EDITBOX_TITLE);
    addEditBox("msg : ", msg.c_str(), "", EDITBOX_MSG);
    addEditBox("ticker : ", ticker.c_str(), "", EDITBOX_TICKER);
    addEditBox("type : ", type.c_str(), "", EDITBOX_TYPE);
    addEditBox("icon : ", icon.c_str(), "", EDITBOX_ICON);
    addEditBox("sound : ", sound.c_str(), "", EDITBOX_SOUND);
    addEditBox("active : ", active.c_str(), "", EDITBOX_ACTIVE);
    addEditBox("after : ", to_string(after).c_str(), "", EDITBOX_AFTER);
}

void PushParamScene::setRegisterLocalPushParam()
{
    string pushID = getEditboxValue(EDITBOX_PUSH_ID);
    string title = getEditboxValue(EDITBOX_TITLE);
    string msg = getEditboxValue(EDITBOX_MSG);
    string ticker = getEditboxValue(EDITBOX_TICKER);
    string type = getEditboxValue(EDITBOX_TYPE);
    string icon = getEditboxValue(EDITBOX_ICON);
    string sound = getEditboxValue(EDITBOX_SOUND);
    string active = getEditboxValue(EDITBOX_ACTIVE);
    string after = getEditboxValue(EDITBOX_AFTER);

    ParameterDataManager::getInstance()->pushParams->setPushID(stoi(pushID));
    ParameterDataManager::getInstance()->pushParams->setTitle(title);
    ParameterDataManager::getInstance()->pushParams->setMsg(msg);
    ParameterDataManager::getInstance()->pushParams->setTicker(ticker);
    ParameterDataManager::getInstance()->pushParams->setType(type);
    ParameterDataManager::getInstance()->pushParams->setIcon(icon);
    ParameterDataManager::getInstance()->pushParams->setSound(sound);
    ParameterDataManager::getInstance()->pushParams->setActive(active);
    ParameterDataManager::getInstance()->pushParams->setAfter(stol(after));
}

Push_BoolType PushParamScene::intToPushUserSetting(int value)
{
    switch (value) {
        case 1:
            return Push_TRUE;
        default:
            return Push_FALSE;
    }
}

==> down.php?SDK=cocos_V1.21.1.1.zip: cocos_V1.21.1.1/Android/sample/c2s/Classes/PushParamScene.cpp <==
//
//  PushParamScene.cpp
//  HIVE_SDK_Cocos_Sample
//
//  Created by sjyong on 2021/10/20.
//

#include "PushParamScene.hpp"
#include "ParameterDataManager.hpp"
#include "C2SPush.h"
#include "ui/CocosGUI.h"

using namespace cocos2d;
using namespace cocos2d::ui;
using namespace hive;

#include <map>

using namespace std;

bool PushParamScene::init()
{
    if(!BaseView::init())
        return false;

    addButton("OK", BUTTON_OK);

    scheduleUpdate();

    return true;
}

void PushParamScene::update(float dt)
{
    BaseView::update(dt);

    static bool firstRun = true;
    if (firstRun) {
        firstRun = false;
    }
}

void PushParamScene::onButtonEvent(int buttonTag)
{
    if (buttonTag != BUTTON_OK) {
        return;
    }

    setCompletionHandler();
    setCompletionHandler = NULL;
    this->popView();
}

void PushParamScene::showParameters(int tag)
{
    api = static_cast<C2SModuleAPIList::PushAPI>(tag);
    switch (api) {
        // Common
        case C2SModuleAPIList::PUSH_SET_AGREE:
        {
            showPushSetAgreeParam([=](){
                int notice = getSelectedToggleButtonIndex(TOGGLE_BUTTON_NOTICE);
                int night = getSelectedToggleButtonIndex(TOGGLE_BUTTON_NIGHT);

                ParameterDataManager::getInstance()->pushParams->setNotice(static_cast<Push_BoolType>(notice));
                ParameterDataManager::getInstance()->pushParams->setNight(static_cast<Push_BoolType>(night));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH:
        {
            showPushRegisterLocalPushParam([=](){
                setRegisterLocalPushParam();
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_EX:
        {
            showPushRegisterLocalPushExParam([=](){
                setRegisterLocalPushParam();

                string broadcastAction = getEditboxValue(EDITBOX_BROADCAST_ACTION);
                ParameterDataManager::getInstance()->pushParams->setBroadcastAction(broadcastAction);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_UNREGISTER_LOCAL_PUSH:
        {
            showPushUnRegisterLocalPushParam([=](){
                string pushID = getEditboxValue(EDITBOX_PUSH_ID);
                ParameterDataManager::getInstance()->pushParams->setPushID(stoi(pushID));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_UID:
        {
            showPushSetUidParam([=](){
                string uid = getEditboxValue(EDITBOX_UID);
                ParameterDataManager::getInstance()->commonParams->setUid(uid);
            });
            break;
        }

        // iOS
        case C2SModuleAPIList::PUSH_SET_FOREGROUND:
        {
            showPushSetForegroundParam([=](){
                int remote = getSelectedToggleButtonIndex(TOGGLE_BUTTON_REMOTE);
                int local = getSelectedToggleButtonIndex(TOGGLE_BUTTON_LOCAL);

                ParameterDataManager::getInstance()->pushParams->setRemote(static_cast<Push_BoolType>(remote));
                ParameterDataManager::getInstance()->pushParams->setLocal(static_cast<Push_BoolType>(local));

            });
            break;
        }

        // Android
        case C2SModuleAPIList::PUSH_SET_PUSH:
        {
            showPushSetPushParam([=](){
                int isPush = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_PUSH);
                ParameterDataManager::getInstance()->pushParams->setIsPush(intToPushUserSetting(isPush));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_SOUND:
        {
            showPushSetSoundParam([=](){
                int isSound = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_SOUND);
                ParameterDataManager::getInstance()->pushParams->setIsSound(intToPushUserSetting(isSound));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_VIB:
        {
            showPushSetVibParam([=](){
                int isVib = getSelectedToggleButtonIndex(TOGGLE_BUTTON_IS_VIB);
                ParameterDataManager::getInstance()->pushParams->setIsVib(intToPushUserSetting(isVib));
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_BIG:
        {
            showPushRegisterLocalPushBigParam([=](){
                setRegisterLocalPushParam();

                string bigmsg = getEditboxValue(EDITBOX_BIG_MSG);
                string broadcastAction = getEditboxValue(EDITBOX_BROADCAST_ACTION);

                ParameterDataManager::getInstance()->pushParams->setBigMsg(bigmsg);
                ParameterDataManager::getInstance()->pushParams->setBroadcastAction(broadcastAction);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_REGISTER_LOCAL_PUSH_DATA:
        {
            showPushRegisterLocalPushDataParam([=](){
                setRegisterLocalPushParam();

                string groupId = getEditboxValue(EDITBOX_GROUP_ID);
                ParameterDataManager::getInstance()->pushParams->setGroupId(groupId);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_OPERATION_LOCAL_PUSH_ON_RUNNING:
        {
            showPushSetOperationLocalPushOnRunningParam([=](){
                int boolean = getSelectedToggleButtonIndex(TOGGLE_BUTTON_BOOLEAN);
                ParameterDataManager::getInstance()->pushParams->setBoolean(boolean);
            });
            break;
        }
        case C2SModuleAPIList::PUSH_SET_OPERATION_GCM_PUSH_ON_RUNNING:
        {
            showPushSetOperationGCMPushOnRunningParam([=](){
                int boolean = getSelectedToggleButtonIndex(TOGGLE_BUTTON_BOOLEAN);
                ParameterDataManager::getInstance()->pushParams->setBoolean(boolean);
            });
            break;
        }
        default:
            break;
    }
}

// MARK: Common
void PushParamScene::showPushSetAgreeParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetAgree -");
    setCompletionHandler = completionHandler;

    Push_BoolType notice = ParameterDataManager::getInstance()->pushParams->getNotice();
    Push_BoolType night = ParameterDataManager::getInstance()->pushParams->getNight();

    addTrueFalseToggleButton("notice : ", int(notice), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_NOTICE);
    addTrueFalseToggleButton("night : ", int(night), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_NIGHT);
}

void PushParamScene::showPushRegisterLocalPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPush -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();
}

void PushParamScene::showPushRegisterLocalPushExParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushEx -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();

    string broadcastAction = ParameterDataManager::getInstance()->pushParams->getBroadcastAction();

    addEditBox("broadcastAction : ", broadcastAction.c_str(), "", EDITBOX_BROADCAST_ACTION);
}

void PushParamScene::showPushUnRegisterLocalPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- UnRegisterLocalPush -");
    setCompletionHandler = completionHandler;

    int pushID = ParameterDataManager::getInstance()->pushParams->getPushID();

    addEditBox("pushID : ", to_string(pushID).c_str(), "", EDITBOX_PUSH_ID);
}

void PushParamScene::showPushSetUidParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetUid -");
    setCompletionHandler = completionHandler;

    string uid = ParameterDataManager::getInstance()->commonParams->getUid();

    addEditBox("pushID : ", uid.c_str(), "", EDITBOX_PUSH_ID);
}

// MARK: iOS
void PushParamScene::showPushSetForegroundParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetForeground -");
    setCompletionHandler = completionHandler;

    Push_BoolType remote = ParameterDataManager::getInstance()->pushParams->getRemote();
    Push_BoolType local = ParameterDataManager::getInstance()->pushParams->getLocal();

    addTrueFalseToggleButton("remote : ", int(remote), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_REMOTE);
    addTrueFalseToggleButton("local : ", int(local), {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_LOCAL);
}

// MARK: Android
void PushParamScene::showPushSetPushParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetPush -");
    setCompletionHandler = completionHandler;

    Push_BoolType isPush = ParameterDataManager::getInstance()->pushParams->getIsPush();
    int isPushValue = 0;
    if(isPush == Push_TRUE) {
        isPushValue = 1;
    } else {
        isPushValue = 0;
    }

    addTrueFalseToggleButton("isPush : ", isPushValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_PUSH);
}

void PushParamScene::showPushSetSoundParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetSound -");
    setCompletionHandler = completionHandler;

    Push_BoolType isSound = ParameterDataManager::getInstance()->pushParams->getIsSound();
    int isSoundValue = 0;
    if(isSound == Push_TRUE) {
        isSoundValue = 1;
    } else {
        isSoundValue = 0;
    }

    addTrueFalseToggleButton("isSound : ", isSoundValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_SOUND);
}

void PushParamScene::showPushSetVibParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetVib -");
    setCompletionHandler = completionHandler;

    Push_BoolType isVib = ParameterDataManager::getInstance()->pushParams->getIsVib();
    int isVibValue = 0;
    if(isVib == Push_TRUE) {
        isVibValue = 1;
    } else {
        isVibValue = 0;
    }

    addTrueFalseToggleButton("isVib : ", isVibValue, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_IS_VIB);
}

void PushParamScene::showPushRegisterLocalPushBigParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushBig -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();

    string bigmsg = ParameterDataManager::getInstance()->pushParams->getBigMsg();
    string broadcastAction = ParameterDataManager::getInstance()->pushParams->getBroadcastAction();

    addEditBox("bigmsg : ", bigmsg.c_str(), "", EDITBOX_BIG_MSG);
    addEditBox("broadcastAction : ", broadcastAction.c_str(), "", EDITBOX_BROADCAST_ACTION);
}

void PushParamScene::showPushRegisterLocalPushDataParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- RegisterLocalPushData -");
    setCompletionHandler = completionHandler;

    addRegisterLocalPushParamButtons();

    string groupId = ParameterDataManager::getInstance()->pushParams->getGroupId();

    addEditBox("groupId : ", groupId.c_str(), "", EDITBOX_GROUP_ID);
}

void PushParamScene::showPushSetOperationLocalPushOnRunningParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetOperationLocalPushOnRunning -");
    setCompletionHandler = completionHandler;

    int boolean = ParameterDataManager::getInstance()->pushParams->getBoolean();

    addTrueFalseToggleButton("boolean : ", boolean, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_BOOLEAN);
}

void PushParamScene::showPushSetOperationGCMPushOnRunningParam(function<void()> completionHandler)
{
    setUseBackButton(true, "- SetOperationGCMPushOnRunning -");
    setCompletionHandler = completionHandler;

    int boolean = ParameterDataManager::getInstance()->pushParams->getBoolean();

    addTrueFalseToggleButton("boolean : ", boolean, {screenSize.width, DEFAULT_CONTENT_HEIGHT}, TOGGLE_BUTTON_BOOLEAN);
}

void PushParamScene::addRegisterLocalPushParamButtons()
{
    int pushID = ParameterDataManager::getInstance()->pushParams->getPushID();
    string title = ParameterDataManager::getInstance()->pushParams->getTitle();
    string msg = ParameterDataManager::getInstance()->pushParams->getMsg();
    string ticker = ParameterDataManager::getInstance()->pushParams->getTicker();
    string type = ParameterDataManager::getInstance()->pushParams->getType();
    string icon = ParameterDataManager::getInstance()->pushParams->getIcon();
    string sound = ParameterDataManager::getInstance()->pushParams->getSound();
    string active = ParameterDataManager::getInstance()->pushParams->getActive();
    long after = ParameterDataManager::getInstance()->pushParams->getAfter();

    addEditBox("pushID : ", to_string(pushID).c_str(), "", EDITBOX_PUSH_ID);
    addEditBox("title : ", title.c_str(), "", EDITBOX_TITLE);
    addEditBox("msg : ", msg.c_str(), "", EDITBOX_MSG);
    addEditBox("ticker : ", ticker.c_str(), "", EDITBOX_TICKER);
    addEditBox("type : ", type.c_str(), "", EDITBOX_TYPE);
    addEditBox("icon : ", icon.c_str(), "", EDITBOX_ICON);
    addEditBox("sound : ", sound.c_str(), "", EDITBOX_SOUND);
    addEditBox("active : ", active.c_str(), "", EDITBOX_ACTIVE);
    addEditBox("after : ", to_string(after).c_str(), "", EDITBOX_AFTER);
}

void PushParamScene::setRegisterLocalPushParam()
{
    string pushID = getEditboxValue(EDITBOX_PUSH_ID);
    string title = getEditboxValue(EDITBOX_TITLE);
    string msg = getEditboxValue(EDITBOX_MSG);
    string ticker = getEditboxValue(EDITBOX_TICKER);
    string type = getEditboxValue(EDITBOX_TYPE);
    string icon = getEditboxValue(EDITBOX_ICON);
    string sound = getEditboxValue(EDITBOX_SOUND);
    string active = getEditboxValue(EDITBOX_ACTIVE);
    string after = getEditboxValue(EDITBOX_AFTER);

    ParameterDataManager::getInstance()->pushParams->setPushID(stoi(pushID));
    ParameterDataManager::getInstance()->pushParams->setTitle(title);
    ParameterDataManager::getInstance()->pushParams->setMsg(msg);
    ParameterDataManager::getInstance()->pushParams->setTicker(ticker);
    ParameterDataManager::getInstance()->pushParams->setType(type);
    ParameterDataManager::getInstance()->pushParams->setIcon(icon);
    ParameterDataManager::getInstance()->pushParams->setSound(sound);
    ParameterDataManager::getInstance()->pushParams->setActive(active);
    ParameterDataManager::getInstance()->pushParams->setAfter(stol(after));
}

Push_BoolType PushParamScene::intToPushUserSetting(int value)
{
    switch (value) {
        case 1:
            return Push_TRUE;
        default:
            return Push_FALSE;
    }
}
